# Table of Contents

- [assign-fact-sheet-owners](<./assign-fact-sheet-owners.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Identify and Assign Fact Sheet Owners](<./Identify-and-Assign-Fact-Sheet-Owners.md>)
  - [Introduction to Fact Sheet Ownership](<./Identify-and-Assign-Fact-Sheet-Owners/Introduction-to-Fact-Sheet-Ownership.md>)
  - [Create Subscription Roles](<./Identify-and-Assign-Fact-Sheet-Owners/Create-Subscription-Roles.md>)
  - [Identify Application Owners](<./Identify-and-Assign-Fact-Sheet-Owners/Identify-Application-Owners.md>)
  - [Assign Application Owners](<./Identify-and-Assign-Fact-Sheet-Owners/Assign-Application-Owners.md>)
  - [Use Surveys to Identify and Assign Application Owners](<./Identify-and-Assign-Fact-Sheet-Owners/Use-Surveys-to-Identify-and-Assign-Application-Owners.md>)
  - [Use Subscriptions to Assign Application Owners](<./Identify-and-Assign-Fact-Sheet-Owners/Use-Subscriptions-to-Assign-Application-Owners.md>)
  - [Monitor Progress Using Metrics](<./Identify-and-Assign-Fact-Sheet-Owners/Monitor-Progress-Using-Metrics.md>)
